===============
qingmi
===============

Qingmi(青咪， 取自 ``情迷`` 谐音， 有 ``亲昵`` 之意)是一个基于Python3+Flask二次开发的应用层框架， 其内部封装了常用的模块和工具集， 主要用于针对flask web快速高效开发。

采用的技术栈：

- python3
- flask
- Werkzeug
- mongoengine
- celery
- fabric
- httpie
- Flask-Script
- Flask-WTF
- flask-mongoengine
- Flask-Login
- Flask-RESTful
- Flask-DebugToolbar
- Flask-Celery-Helper
- requests
- Flask-Caching
- Flask-Admin
- Flask-Uploads
- ipython
- Pillow
- click

功能特性：

- 数据统计
- 短信发送
- 邮件发送
- 文件上传
- 验证码
- 静态文件
- IP处理
- 日志
- 通用模块
- 用户模块
- 权限管理
- 动态配置
- 定时任务(任务调度)
- 通用API
- 第三方登录
- 微信公众平台
- 部署
- 辅助工具helper(加解密[hash/md5]/json/http/ip/日志/正则表达式/时间和日期/...)
- 单元测试

用法
====


文档
====


